@@ -1,2 +1,3 @@
-cGroupsWUI <- function(port = 8102L)
-  shiny::runApp(system.file("app", package="compareGroups"), port)
\ No newline at end of file
+cGroupsWUI <- function(port = 8102L){
+  shiny::runApp(system.file("app", package="compareGroups"), port)
+}
\ No newline at end of file
